pub trait SmartContractHandle<AccountId> {
// Required methods
fn evm(address: H160) -> Self;
fn wasm(address: AccountId) -> Self;
}Expand description
Trait defining the interface for dApp staking smart contract types handler.
It can be used to create a representation of the specified smart contract instance type.
Required Methods
Sourcefn evm(address: H160) -> Self
fn evm(address: H160) -> Self
Create a new smart contract representation for the specified EVM address.
Sourcefn wasm(address: AccountId) -> Self
fn wasm(address: AccountId) -> Self
Create a new smart contract representation for the specified Wasm address.
Deprecated
Wasm (ink!) smart contracts have been decommissioned together with pallet-contracts.
No new Wasm dApp can be registered; this constructor is only kept so that historic
storage entries remain decodable. It will be removed once dApp staking storage on all
networks is provably free of SmartContract::Wasm entries.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.